# TODO

- Implement web_fetch tool.
- Add sandboxing configuration files for users to take away, at least for sandbox-exec and Docker.
- Implement additional restrictions for the shell tool.
- Make paths relative to config.wd.
